@@ -1,38 +1,10 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  quota module: handles partition related commands
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2006-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2006-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
 import univention.management.console as umc
@@ -46,7 +18,7 @@ from univention.management.console.modules.quota import df, tools
 _ = umc.Translation('univention-management-console-module-quota').translate
 
 
-class Commands(object):
+class Commands:
 
     def partitions_query(self, request):
         result = []
@@ -54,7 +26,7 @@ class Commands(object):
             fs = fstab.File('/etc/fstab')
             mt = fstab.File('/etc/mtab')
         except OSError as error:
-            MODULE.error('Could not open %s' % error.filename)
+            MODULE.error('Could not open %s', error.filename)
             raise UMC_Error(_('Could not open %s') % error.filename, 500)
 
         partitions = fs.get(['xfs', 'ext4', 'ext3', 'ext2'], False)
@@ -79,7 +51,7 @@ class Commands(object):
             fs = fstab.File('/etc/fstab')
             mt = fstab.File('/etc/mtab')
         except OSError as error:
-            MODULE.error('Could not open %s' % error.filename)
+            MODULE.error('Could not open %s', error.filename)
             raise UMC_Error(_('Could not open %s') % error.filename, 500)
 
         partition = fs.find(spec=request.options['partitionDevice'])
@@ -96,7 +68,7 @@ class Commands(object):
 
     @simple_response
     def partitions_activate(self, partitionDevice):
-        MODULE.info('quota/partitions/activate: %s' % (partitionDevice,))
+        MODULE.info('quota/partitions/activate: %s', partitionDevice)
 
         def _thread(self, request):
             return tools.activate_quota(partitionDevice, True)
@@ -104,7 +76,7 @@ class Commands(object):
 
     @simple_response
     def partitions_deactivate(self, partitionDevice):
-        MODULE.info('quota/partitions/deactivate: %s' % (partitionDevice,))
+        MODULE.info('quota/partitions/deactivate: %s', partitionDevice)
 
         def _thread(self, request):
             return tools.activate_quota(partitionDevice, False)
